@@ -51,19 +51,21 @@ class TheOneRingConnection(
 	capabilities.CapabilitiesMixin,
 ):
 
-	# Overriding a base class variable
-	# Should the forwarding number be handled by the alias or by an option?
+	# overiding base class variable
 	_mandatory_parameters = {
 		'account' : 's',
 		'password' : 's',
 	}
-	# Overriding a base class variable
+	# overiding base class variable
 	_optional_parameters = {
 		'forward' : 's',
 	}
 	_parameter_defaults = {
 		'forward' : '',
 	}
+	_secret_parameters = set((
+		"password",
+	))
 
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def __init__(self, manager, parameters):
@@ -290,7 +292,7 @@ class TheOneRingConnection(
 		"""
 		@note Maemo specific
 
-		@todo Make this delayed to handle background switching of networks
+		@todo Make this delayed to handle background switching of networks.  First I need to verify I receive connected
 		"""
 		status = event.get_status()
 		error = event.get_error()
@@ -307,3 +309,5 @@ class TheOneRingConnection(
 				self._disconnect()
 			except Exception:
 				_moduleLogger.exception("Error durring disconnect")
+		else:
+			_moduleLogger.info("Other status: %r" % (status, ))
