@@ -1,8 +1,7 @@
 #!/usr/bin/env python
 
 """
-@todo Look into switching from POLL_TIME = min(F * 2^n, MAX) to POLL_TIME = min(CONST + F * 2^n, MAX)
-@todo Look into supporting more states that have a different F and MAX
+@todo Look into supporting more states
 """
 
 import logging
@@ -177,6 +176,7 @@ class UpdateStateMachine(StateMachine):
 		_moduleLogger.info("%s Starting State Machine" % (self._name, ))
 
 	def stop(self):
+		_moduleLogger.info("%s Stopping State Machine" % (self._name, ))
 		self._stop_update()
 
 	def close(self):
@@ -197,6 +197,7 @@ class UpdateStateMachine(StateMachine):
 		return self._state
 
 	def reset_timers(self):
+		_moduleLogger.info("%s Resetting State Machine" % (self._name, ))
 		self._reset_timers()
 
 	@property
@@ -220,7 +221,7 @@ class UpdateStateMachine(StateMachine):
 		nextTimeout = self._strategy.timeout
 		if nextTimeout != self.INFINITE_PERIOD:
 			self._timeoutId = gobject.timeout_add(nextTimeout, self._on_timeout)
-		_moduleLogger.debug("%s Next update in %s ms" % (self._name, nextTimeout, ))
+		_moduleLogger.info("%s Next update in %s ms" % (self._name, nextTimeout, ))
 
 	def _stop_update(self):
 		if self._timeoutId is None:
@@ -237,7 +238,6 @@ class UpdateStateMachine(StateMachine):
 
 	@gtk_toolbox.log_exception(_moduleLogger)
 	def _on_timeout(self):
-		_moduleLogger.info("%s Update" % (self._name))
 		self._timeoutId = None
 		self._schedule_update()
 		for item in self._updateItems:
